summaryrefslogtreecommitdiffstats
path: root/controller-server
diff options
context:
space:
mode:
authorJon Marius Venstad <jvenstad@yahoo-inc.com>2018-03-20 17:59:56 +0100
committerJon Marius Venstad <jvenstad@yahoo-inc.com>2018-03-20 17:59:56 +0100
commit9c8fbd98d7ca8756a6c24daaf70c244fa67531d5 (patch)
tree4903e292e4a312ad116d07d2ebc8abf28ab920aa /controller-server
parent9746bf54689cda8f2b653c8bacc9c718fc159695 (diff)
G minor
Diffstat (limited to 'controller-server')
-rw-r--r--controller-server/src/test/java/com/yahoo/vespa/hosted/controller/deployment/DeploymentTriggerTest.java4
1 files changed, 3 insertions, 1 deletions
diff --git a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/deployment/DeploymentTriggerTest.java b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/deployment/DeploymentTriggerTest.java
index 339cb078225..2dc90563580 100644
--- a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/deployment/DeploymentTriggerTest.java
+++ b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/deployment/DeploymentTriggerTest.java
@@ -394,8 +394,10 @@ public class DeploymentTriggerTest {
tester.deployAndNotify(application, Optional.empty(), false, true, productionEuWest1);
assertTrue(tester.deploymentQueue().jobs().isEmpty());
// The below should now deploy the new application version, even though the platform version is already deployed.
tester.deployCompletely(application, applicationPackage, BuildJob.defaultBuildNumber + 1);
+ assertEquals(ApplicationVersion.from(BuildJob.defaultSourceRevision, BuildJob.defaultBuildNumber + 1),
+ app.get().deployments().get(ZoneId.from("prod.us-central-1")).applicationVersion());
}
@Test
@@ -394,8 +394,10 @@ public class DeploymentTriggerTest {
tester.deployAndNotify(application, Optional.empty(), false, true, productionEuWest1);
assertTrue(tester.deploymentQueue().jobs().isEmpty());
- // The below should now deploy the new application version, even though the platform version is already deployed.
+ // Deploy the new application version, even though the platform version is already deployed in us-central-1.
tester.deployCompletely(application, applicationPackage, BuildJob.defaultBuildNumber + 1);